@@ -32,14 +32,14 @@ class biometa(SQLModel, table=True):  # type: ignore
     """Metadata is a combination of biosample and experiment."""
 
     id: Optional[int] = Field(default=None, primary_key=True)
-    biosample_id: int = Field(default=None, foreign_key="biosample.id")
-    readout_type_id: int = Field(default=None, foreign_key="readout_type.id")
-    featureset_id: int = Field(default=None, foreign_key="featureset.id")
     experiment_id: int = Field(default=None, foreign_key="experiment.id")
+    biosample_id: int = Field(default=None, foreign_key="biosample.id")
+    readout_id: int = Field(default=None, foreign_key="readout.id")
+    featureset_id: int = Field(default=None, foreign_key="featureset.id")
 
 
-class readout_type(SQLModel, table=True):  # type: ignore
-    """Readout type of experiments."""
+class readout(SQLModel, table=True):  # type: ignore
+    """Readout of experiments."""
 
     id: Optional[int] = Field(default=None, primary_key=True)
     efo_id: Optional[str] = None
